@@ -25,7 +25,7 @@
  */
 
 /*
- *  Copyright (C) 2004-2014 Max-Planck-Society
+ *  Copyright (C) 2004-2015 Max-Planck-Society
  *  Author: Martin Reinecke
  */
 
@@ -65,6 +65,15 @@ Candidates for testing the validity of the Healpix routines:
 
 using namespace std;
 
+#define UNITTESTS
+
+#ifdef UNITTESTS
+int errcount=0;
+#define FAIL(a) {a; if (++errcount>100) planck_fail("unit test errors");}
+#else
+#define FAIL(a) a;
+#endif
+
 const int nsamples = 1000000;
 
 planck_rng rng;
@@ -353,7 +362,7 @@ template<typename I> void check_rangeset()
   planck_assert(!b.overlaps(makeRS<I>("0 20 31 40 51 100")),"error");
   }
   {
-  const int niter = 100;
+  const int niter = 1000;
   for (int iter=0; iter<niter; ++iter)
     {
     rangeset<I> a = randomRangeSet<I>(1000, 0, 100);
@@ -451,7 +460,7 @@ template<typename I> void check_ringnestring()
       {
       I pix = I(rng.rand_uni()*base.Npix());
       if (base.ring2nest(base.nest2ring(pix))!=pix)
-        cout << "  PROBLEM: order = " << order << ", pixel = " << pix << endl;
+        FAIL(cout<<"  PROBLEM: order = "<<order<<", pixel = "<<pix<<endl)
       }
     }
   }
@@ -466,7 +475,7 @@ template<typename I> void check_nestpeanonest()
       {
       I pix = I(rng.rand_uni()*base.Npix());
       if (base.peano2nest(base.nest2peano(pix))!=pix)
-        cout << "  PROBLEM: order = " << order << ", pixel = " << pix << endl;
+        FAIL(cout<<"  PROBLEM: order = "<<order<<", pixel = "<<pix<<endl)
       }
     }
   }
@@ -484,10 +493,10 @@ template<typename I> void check_pixzphipix()
       I pix = I(rng.rand_uni()*base1.Npix());
       base1.pix2zphi(pix,z,phi);
       if (base1.zphi2pix(z,phi)!=pix)
-        cout << "  PROBLEM: order = " << order << ", pixel = " << pix << endl;
+        FAIL(cout<<"  PROBLEM: order = "<<order<<", pixel = "<<pix<<endl)
       base2.pix2zphi(pix,z,phi);
       if (base2.zphi2pix(z,phi)!=pix)
-        cout << "  PROBLEM: order = " << order << ", pixel = " << pix << endl;
+        FAIL(cout<<"  PROBLEM: order = "<<order<<", pixel = "<<pix<<endl)
       }
     }
   for (I nside=3; nside<(I(1)<<omax); nside+=nside/2+1)
@@ -499,7 +508,7 @@ template<typename I> void check_pixzphipix()
       I pix = I(rng.rand_uni()*base.Npix());
       base.pix2zphi(pix,z,phi);
       if (base.zphi2pix(z,phi)!=pix)
-        cout << "  PROBLEM: nside = " << nside << ", pixel = " << pix << endl;
+        FAIL(cout<<"  PROBLEM: nside = "<<nside<<", pixel = "<<pix<<endl)
       }
     }
   }
@@ -518,12 +527,12 @@ template<typename I> void check_zphipixzphi()
       random_zphi (z,phi);
       base1.pix2zphi(base1.zphi2pix(z,phi),z2,phi2);
       if (cosdist_zphi(z,phi,z2,phi2)<mincos)
-        cout << "  PROBLEM: order = " << order
-             << ", zphi = " << z << ", " << phi << endl;
+        FAIL(cout << "  PROBLEM: order = " << order
+                  << ", zphi = " << z << ", " << phi << endl)
       base2.pix2zphi(base2.zphi2pix(z,phi),z2,phi2);
       if (cosdist_zphi(z,phi,z2,phi2)<mincos)
-        cout << "  PROBLEM: order = " << order
-             << ", zphi = " << z << ", " << phi << endl;
+        FAIL(cout << "  PROBLEM: order = " << order
+                  << ", zphi = " << z << ", " << phi << endl)
       }
     }
   for (int nside=3; nside<(I(1)<<omax); nside+=nside/2+1)
@@ -536,8 +545,8 @@ template<typename I> void check_zphipixzphi()
       random_zphi (z,phi);
       base.pix2zphi(base.zphi2pix(z,phi),z2,phi2);
       if (cosdist_zphi(z,phi,z2,phi2)<mincos)
-        cout << "  PROBLEM: nside = " << nside
-             << ", zphi = " << z << ", " << phi << endl;
+        FAIL(cout << "  PROBLEM: nside = " << nside
+                  << ", zphi = " << z << ", " << phi << endl)
       }
     }
   }
@@ -553,9 +562,9 @@ template<typename I> void check_pixangpix()
       {
       I pix = I(rng.rand_uni()*base1.Npix());
       if (base1.ang2pix(base1.pix2ang(pix))!=pix)
-        cout << "  PROBLEM: order = " << order << ", pixel = " << pix << endl;
+        FAIL(cout<<"  PROBLEM: order = "<<order<<", pixel = "<<pix<<endl)
       if (base2.ang2pix(base2.pix2ang(pix))!=pix)
-        cout << "  PROBLEM: order = " << order << ", pixel = " << pix << endl;
+        FAIL(cout<<"  PROBLEM: order = "<<order<<", pixel = "<<pix<<endl)
       }
     }
   for (I nside=3; nside<(I(1)<<omax); nside+=nside/2+1)
@@ -565,7 +574,7 @@ template<typename I> void check_pixangpix()
       {
       I pix = I(rng.rand_uni()*base.Npix());
       if (base.ang2pix(base.pix2ang(pix))!=pix)
-        cout << "  PROBLEM: nside = " << nside << ", pixel = " << pix << endl;
+        FAIL(cout<<"  PROBLEM: nside = "<<nside<<", pixel = "<<pix<<endl)
       }
     }
   }
@@ -599,9 +608,9 @@ template<typename I> void check_neighbors()
         else
           {
           if (v_angle(base.pix2vec(nb[n]),pixpt)>maxang)
-            cout << " PROBLEM: order = " << order << ", pix = " << pix << endl;
+            FAIL(cout<<"  PROBLEM: order = "<<order<<", pix = "<<pix<<endl)
           if ((n>0) && (nb[n]==nb[n-1]))
-            cout << " PROBLEM: order = " << order << ", pix = " << pix << endl;
+            FAIL(cout<<"  PROBLEM: order = "<<order<<", pix = "<<pix<<endl)
           }
         }
       planck_assert((check<=1)||((order==0)&&(check<=2)),"too few neighbors");
@@ -619,7 +628,7 @@ template<typename I> void check_neighbors()
       base.neighbors(pix,nb);
       for (int n=0; n<8; ++n)
         if ((nb[n]>=0) && (v_angle(base.pix2vec(nb[n]),pixpt)>maxang))
-          cout << "  PROBLEM: nside = " << nside << ", pix = " << pix << endl;
+          FAIL(cout<<"  PROBLEM: nside = "<<nside<<", pix = "<<pix<<endl)
       }
     }
   }
@@ -636,7 +645,33 @@ void check_swap_scheme()
     map.swap_scheme();
     for (int m=0; m<map.Npix(); ++m)
       if (map[m]!=(m&0xFF))
-        cout << "  PROBLEM: order = " << order << ", pix = " << m << endl;
+        FAIL(cout<<"  PROBLEM: order = "<<order<<", pix = "<<m<<endl)
+    }
+  }
+
+void check_issue_229 (Healpix_Ordering_Scheme scheme)
+  {
+  cout << "checking issue #229" << endl;
+  int order=8;
+  Healpix_Map<bool> map (order,scheme);
+  map.fill(false);
+  Healpix_Map<vec3> vmap(order,scheme);
+  for (int m=0; m<vmap.Npix(); ++m)
+    vmap[m]=vmap.pix2vec(m);
+  rangeset<int> pixset;
+  pointing ptg(halfpi-0.1,0);
+  double rad=0.1;
+  map.query_disc(ptg,rad,pixset);
+  vec3 vptg=ptg;
+  double cosrad=cos(rad);
+  for (tsize j=0; j<pixset.nranges(); ++j)
+    for (int i=pixset.ivbegin(j); i<pixset.ivend(j); ++i)
+      map[i] = true;
+  for (int i=0; i<map.Npix(); ++i)
+    {
+    bool inside = dotprod(vmap[i],vptg)>cosrad;
+    if (inside^map[i])
+      FAIL(cout << "  PROBLEM: issue 229" << endl)
     }
   }
 
@@ -645,6 +680,7 @@ void check_query_disc_strict (Healpix_Ordering_Scheme scheme)
   cout << "testing whether all pixels found by query_disc() really" << endl
        << "lie inside the disk (and vice versa)" << endl;
   cout << "Ordering scheme: " << (scheme==RING ? "RING" : "NEST") << endl;
+  rng.seed(42);
   for (int order=0; order<=5; ++order)
     {
     Healpix_Map<bool> map (order,scheme);
@@ -668,7 +704,7 @@ void check_query_disc_strict (Healpix_Ordering_Scheme scheme)
         {
         bool inside = dotprod(vmap[i],vptg)>cosrad;
         if (inside^map[i])
-          cout << "  PROBLEM: order = " << order << ", ptg = " << ptg << endl;
+          FAIL(cout<<"  PROBLEM: order = "<<order<<", ptg = "<<ptg<<endl)
         }
       for (tsize j=0; j<pixset.nranges(); ++j)
         for (int i=pixset.ivbegin(j); i<pixset.ivend(j); ++i)
@@ -680,6 +716,7 @@ void check_query_disc_strict (Healpix_Ordering_Scheme scheme)
 template<typename I>void check_query_disc()
   {
   cout << "checking query_disc() " << bname<I>() << endl;
+  rng.seed(48);
   int omax=min<int>(20,T_Healpix_Base<I>::order_max);
   for (int order=0; order<=omax; ++order)
     {
@@ -698,7 +735,7 @@ template<typename I>void check_query_disc()
         rangeset<I> psi;
         rbase.query_disc_inclusive(ptg,rad,psi,fct);
         if (!psi.contains(pslast))
-          cout << "  PROBLEM: RING pixel sets inconsistent" << endl;
+          cout << "  Potential problem: RING pixel sets inconsistent" << endl;
         swap(pslast,psi);
         }
       I nval = pixset.nval();
@@ -709,18 +746,19 @@ template<typename I>void check_query_disc()
         rangeset<I> psi;
         nbase.query_disc_inclusive(ptg,rad,psi,fct);
         if (!psi.contains(pslast))
-          cout << "  PROBLEM: NEST pixel sets inconsistent" << endl;
+          FAIL(cout << "  PROBLEM: NEST pixel sets inconsistent" << endl)
         swap(pslast,psi);
         }
       if (nval!=pixset.nval())
-        cout << "  PROBLEM: number of pixels different: "
-             << nval << " vs. " << pixset.nval() << endl;
+        FAIL(cout << "  PROBLEM: number of pixels different: "
+                  << nval << " vs. " << pixset.nval() << endl)
       }
     }
   }
 template<typename I>void check_query_polygon()
   {
   cout << "checking query_polygon() " << bname<I>() << endl;
+  rng.seed(42);
   int omax=min<int>(20,T_Healpix_Base<I>::order_max);
   for (int order=0; order<=omax; ++order)
     {
@@ -735,18 +773,18 @@ template<typename I>void check_query_polygon()
       I nval = pixset.nval();
       nbase.query_polygon(corner,pixset);
       if (nval!=pixset.nval())
-        cout << "  PROBLEM: number of pixels different: "
-             << nval << " vs. " << pixset.nval() << endl;
+        FAIL(cout << "  PROBLEM: number of pixels different: "
+                  << nval << " vs. " << pixset.nval() << endl)
       rbase.query_polygon_inclusive(corner,pixset,4);
       I nv1=pixset.nval();
       nbase.query_polygon_inclusive(corner,pixset,4);
       I nv2=pixset.nval();
       if (nv1<nv2)
-        cout << "  PROBLEM: inclusive(RING)<inclusive(NEST): "
-             << nv1 << " vs. " << nv2 << endl;
+        FAIL(cout << "  PROBLEM: inclusive(RING)<inclusive(NEST): "
+                  << nv1 << " vs. " << nv2 << endl)
       if (nv2<nval)
-        cout << "  PROBLEM: inclusive(NEST)<non-inclusive: "
-             << nv2 << " vs. " << nval << endl;
+        FAIL(cout << "  PROBLEM: inclusive(NEST)<non-inclusive: "
+                  << nv2 << " vs. " << nval << endl)
       }
     }
   }
@@ -759,7 +797,7 @@ void helper_oop (int order)
   map3.Import(map2);
   for (int m=0; m<map.Npix(); ++m)
     if (!approx(map[m],map3[m],1e-12))
-      cout << "PROBLEM: order = " << order << endl;
+      FAIL(cout << "PROBLEM: order = " << order << endl)
   }
 void helper_udgrade (int order, Healpix_Ordering_Scheme s1,
   Healpix_Ordering_Scheme s2)
@@ -770,7 +808,7 @@ void helper_udgrade (int order, Healpix_Ordering_Scheme s1,
   map3.Import(map2);
   for (int m=0; m<map.Npix(); ++m)
     if (!approx(map[m],map3[m],1e-12))
-      cout << "PROBLEM: order = " << order << endl;
+      FAIL(cout << "PROBLEM: order = " << order << endl)
   }
 void helper_udgrade2 (int nside)
   {
@@ -781,7 +819,7 @@ void helper_udgrade2 (int nside)
   map3.Import(map2);
   for (int m=0; m<map.Npix(); ++m)
     if (!approx(map[m],map3[m],1e-12))
-      cout << "PROBLEM: nside = " << nside << endl;
+      FAIL(cout << "PROBLEM: nside = " << nside << endl)
   }
 
 void check_import()
@@ -811,8 +849,8 @@ void check_average()
       map[m] = rng.rand_uni()+0.01;
     map2.Import(map);
     double avg=map.average(), avg2=map2.average();
-    if (!approx(avg,avg2,1e-10))
-      cout << "PROBLEM: order = " << order << " " << avg/avg2-1 << endl;
+    if (!approx(avg,avg2,1e-13))
+      FAIL(cout << "PROBLEM: order = " << order << " " << avg/avg2-1 << endl)
     }
   for (int nside=3; nside<1000; nside += nside/2+1)
     {
@@ -821,8 +859,8 @@ void check_average()
       map[m] = rng.rand_uni()+0.01;
     map2.Import(map);
     double avg=map.average(), avg2=map2.average();
-    if (!approx(avg,avg2,1e-10))
-      cout << "PROBLEM: nside = " << nside << " " << avg/avg2-1 << endl;
+    if (!approx(avg,avg2,1e-13))
+      FAIL(cout << "PROBLEM: nside = " << nside << " " << avg/avg2-1 << endl)
     }
   }
 
@@ -833,17 +871,21 @@ void random_alm (Alm<xcomplex<double> >&almT, Alm<xcomplex<double> >&almG,
 
   for (int l=0; l<=lmax; ++l)
     {
-    almT(l,0).re=rng.rand_gauss(); almT(l,0).im=0.;
-    almG(l,0).re=rng.rand_gauss(); almG(l,0).im=0.;
-    almC(l,0).re=rng.rand_gauss(); almC(l,0).im=0.;
+    almT(l,0)=dcomplex(rng.rand_gauss(),0.);
+    almG(l,0)=dcomplex(rng.rand_gauss(),0.);
+    almC(l,0)=dcomplex(rng.rand_gauss(),0.);
     }
 
   for (int m=1; m<=mmax; ++m)
     for (int l=m; l<=lmax; ++l)
       {
-      almT(l,m).re=rng.rand_gauss(); almT(l,m).im=rng.rand_gauss();
-      almG(l,m).re=rng.rand_gauss(); almG(l,m).im=rng.rand_gauss();
-      almC(l,m).re=rng.rand_gauss(); almC(l,m).im=rng.rand_gauss();
+      double t1,t2;
+      t1=rng.rand_gauss(); t2=rng.rand_gauss();
+      almT(l,m)=xcomplex<double>(t1,t2);
+      t1=rng.rand_gauss(); t2=rng.rand_gauss();
+      almG(l,m)=xcomplex<double>(t1,t2);
+      t1=rng.rand_gauss(); t2=rng.rand_gauss();
+      almC(l,m)=xcomplex<double>(t1,t2);
       }
   almG(0,0)=almC(0,0)=almG(1,0)=almC(1,0)=almG(1,1)=almC(1,1)=0;
   }
@@ -853,11 +895,15 @@ void random_alm (Alm<xcomplex<double> >&alm, int lmax, int mmax)
   alm.Set(lmax,mmax);
 
   for (int l=0; l<=lmax; ++l)
-    { alm(l,0).re=rng.rand_gauss(); alm(l,0).im=0.; }
+    { alm(l,0)=dcomplex(rng.rand_gauss(),0.); }
 
   for (int m=1; m<=mmax; ++m)
     for (int l=m; l<=lmax; ++l)
-      { alm(l,m).re=rng.rand_gauss(); alm(l,m).im=rng.rand_gauss(); }
+      {
+      double t1,t2;
+      t1=rng.rand_gauss(); t2=rng.rand_gauss();
+      alm(l,m)=xcomplex<double>(t1,t2);
+      }
   }
 
 void check_alm (const Alm<xcomplex<double> >&oalm,
@@ -866,10 +912,10 @@ void check_alm (const Alm<xcomplex<double> >&oalm,
   for (int m=0; m<=alm.Mmax(); ++m)
     for (int l=m; l<=alm.Lmax(); ++l)
       {
-      if (!abs_approx(oalm(l,m).re,alm(l,m).re,epsilon))
-        cout << "Problemr " << l << " " << m << endl;
-      if (!abs_approx(oalm(l,m).im,alm(l,m).im,epsilon))
-        cout << "Problemi " << l << " " << m <<  endl;
+      if (!abs_approx(oalm(l,m).real(),alm(l,m).real(),epsilon))
+        FAIL(cout << "Problemr " << l << " " << m << endl)
+      if (!abs_approx(oalm(l,m).imag(),alm(l,m).imag(),epsilon))
+        FAIL(cout << "Problemi " << l << " " << m <<  endl)
       }
   }
 
@@ -942,8 +988,8 @@ void check_isqrt()
   {
   cout << "testing whether isqrt() works reliably" << endl;
   uint64 val=uint64(0xF234)<<16, valsq=val*val;
-  if (isqrt(valsq)!=val) cout << "PROBLEM1" << endl;
-  if (isqrt(valsq-1)!=val-1) cout << "PROBLEM2" << endl;
+  if (isqrt(valsq)!=val) FAIL(cout << "PROBLEM1" << endl)
+  if (isqrt(valsq-1)!=val-1) FAIL(cout << "PROBLEM2" << endl)
   }
 
 void check_pix2ang_acc()
@@ -953,7 +999,7 @@ void check_pix2ang_acc()
     {
     Healpix_Base2 base(m,RING);
     if (base.pix2ang(1).theta==0.)
-      cout << "PROBLEM: order " << m << endl;
+      FAIL(cout << "PROBLEM: order " << m << endl)
     }
   }
 
@@ -1263,6 +1309,7 @@ void perftest()
 
   if (dummy<0) cout << dummy << endl;
   }
+
 } // unnamed namespace
 
 int main(int argc, const char **argv)
@@ -1300,8 +1347,13 @@ int main(int argc, const char **argv)
   check_swap_scheme();
   check_query_disc_strict(RING);
   check_query_disc_strict(NEST);
+  check_issue_229(RING);
+  check_issue_229(NEST);
   check_query_disc<int>();
   check_query_disc<int64>();
   check_query_polygon<int>();
   check_query_polygon<int64>();
+#ifdef UNITTESTS
+  if (errcount>0) planck_fail("unit test errors");
+#endif
   }
