@@ -704,14 +704,62 @@ class HpxOrthographicAxes(OrthographicAxes):
         f = lambda x,y,z: pixelfunc.vec2pix(nside,x,y,z,nest=nest)
         return super(HpxOrthographicAxes,self).projmap(map,f,**kwds)
 
+class AzimuthalAxes(SphericalProjAxes):
+    """Define an Azimuthal Axes to handle azimuthal equidistant or
+       Lambert azimuthal equal-area projections.
+
+    Input:
+      - rot=, coord= : define rotation and coordinate system. See rotator.
+      - coordprec= : number of digit after floating point for coordinates display.
+      - format= : format string for value display.
+
+      Other keywords from Axes (see Axes).
+    """
+    def __init__(self,*args,**kwds):
+        kwds.setdefault('coordprec',3)
+        super(AzimuthalAxes,self).__init__(P.AzimuthalProj, *args,**kwds)
+        self._do_border = False
+
+    def projmap(self,map,vec2pix_func,xsize=200,ysize=None,reso=1.5,lamb=True,half_sky=False,**kwds):
+        self.proj.set_proj_plane_info(xsize=xsize,ysize=ysize,reso=reso,lamb=lamb,half_sky=half_sky)
+        return super(AzimuthalAxes,self).projmap(map,vec2pix_func,**kwds)
+
+class HpxAzimuthalAxes(AzimuthalAxes):
+    def projmap(self,map,nest=False,**kwds):
+        nside = pixelfunc.npix2nside(pixelfunc.get_map_size(map))
+        f = lambda x,y,z: pixelfunc.vec2pix(nside,x,y,z,nest=nest)
+        xsize = kwds.pop('xsize',800)
+        ysize = kwds.pop('ysize',None)
+        reso = kwds.pop('reso',1.5)
+        lamb = kwds.pop('lamb',True)
+        return super(HpxAzimuthalAxes,self).projmap(map,f,xsize=xsize,
+                                            ysize=ysize,reso=reso,lamb=lamb,**kwds)
 
 ###################################################################
 #
-#   Table color for mollview and gnomview, ...
+#   Table color for mollview, gnomview, and orthview.
+#   Currently defined for so that the default colormap, found in 
+#   matplotlib.rcParams['image.cmap'], the data is displayed with
+#   values greater than vmax as the final element of the colormap,
+#   masked indices gray, and the background set to white.
+#
+#   With matplotlib.rcParams['image.cmap'] assigned to a string
+#   corresponding to a standard matplotlib colormap, one can call
+#   hp.mollview(m) and have the map projected in the standard way,
+#   whereas using just, e.g., hp.mollview(m, cmap='jet') will display
+#   the data with a non-white background.
+#
+#   One can set the default colormap in the matplotlibrc file, or set
+#   it in situ:
+#   >>> matplotlib.rcParam['image.cmap'] = 'coolwarm'
+#   >>> hp.mollview(m)
+#   Note that custom colormaps can also be used, but they need to be 
+#   registered ahead fo time, as shown in
+#   http://matplotlib.org/examples/pylab_examples/custom_cmap.html
 
 def get_color_table(vmin,vmax,val,cmap=None,norm=None):
     # Create color table
-    newjet = create_colormap(cmap)
+    newcmap = create_colormap(cmap)
     if type(norm) is str:
         if norm.lower().startswith('log'):
             norm = LogNorm2(clip=False)
@@ -726,14 +774,17 @@ def get_color_table(vmin,vmax,val,cmap=None,norm=None):
     norm.vmax = vmax
     norm.autoscale_None(val)
     
-    return newjet,norm
+    return newcmap,norm
 
 def create_colormap(cmap):
     if cmap is not None:
         return cmap 
-    cmap0 = matplotlib.cm.jet
-    newcm = matplotlib.colors.LinearSegmentedColormap('newcm',cmap0._segmentdata,
-                                               cmap0.N)
+    cmap0 = matplotlib.cm.get_cmap(matplotlib.rcParams['image.cmap'])
+    if hasattr(cmap0, '_segmentdata'):
+        newcm = matplotlib.colors.LinearSegmentedColormap('newcm',cmap0._segmentdata,
+                                                    cmap0.N)
+    else:
+        newcm = cmap0
     newcm.set_over(newcm(1.0))
     newcm.set_under('w')
     newcm.set_bad('gray')
