@@ -28,6 +28,9 @@ class TestNoCrash(unittest.TestCase):
     def test_orthview_nocrash(self):
         orthview(self.m)
 
+    def test_azeqview_nocrash(self):
+        azeqview(self.m)
+
     def test_mollzoom_nocrash(self):
         mollzoom(self.m)
 
@@ -45,3 +48,6 @@ class TestNoCrash(unittest.TestCase):
 
     def test_mollzoom_ma_nocrash(self):
         mollzoom(self.ma)
+
+    def test_azeqview_ma_nocrash(self):
+        azeqview(self.ma)
